# Table of Contents

Everything

## Modules

nsi.granulate
nsi.granulate.FileUtils
nsi.granulate.GranularUtils
nsi.granulate.Granulate'
nsi.granulate.GranulateOffice'
nsi.granulate.GranulatePDF'
nsi.granulate.template
nsi.granulate.tests
nsi.granulate.tests.data
nsi.granulate.tests.testGranulate
nsi.granulate.tests.testGranulateDOC
nsi.granulate.tests.testGranulateOffice
nsi.granulate.tests.testGranulatePDF

[hide private]